# SPDX-FileCopyrightText: 2025 CoreWeave, Inc.
# SPDX-License-Identifier: Apache-2.0
# SPDX-PackageName: cwsandbox-client

"""Vendored protobuf/gRPC stubs for the CoreWeave Sandbox API.

These files were generated from coreweave/aviato/v1beta1/*.proto and
vendored here to eliminate the buf.build registry dependency.
"""
