# SPDX-FileCopyrightText: 2025 CoreWeave, Inc.
# SPDX-License-Identifier: Apache-2.0
# SPDX-PackageName: cwsandbox-client
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: coreweave/aviato/v1beta1/streaming.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'coreweave/aviato/v1beta1/streaming.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(coreweave/aviato/v1beta1/streaming.proto\x12\x18\x63oreweave.aviato.v1beta1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa9\x02\n\x11\x45xecStreamRequest\x12>\n\x04init\x18\x01 \x01(\x0b\x32(.coreweave.aviato.v1beta1.ExecStreamInitH\x00R\x04init\x12@\n\x05stdin\x18\x02 \x01(\x0b\x32(.coreweave.aviato.v1beta1.ExecStreamDataH\x00R\x05stdin\x12\x44\n\x06resize\x18\x03 \x01(\x0b\x32*.coreweave.aviato.v1beta1.ExecStreamResizeH\x00R\x06resize\x12\x41\n\x05\x63lose\x18\x04 \x01(\x0b\x32).coreweave.aviato.v1beta1.ExecStreamCloseH\x00R\x05\x63loseB\t\n\x07request\"\xb2\x02\n\x0e\x45xecStreamInit\x12\"\n\nsandbox_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tsandboxId\x12\x1d\n\x07\x63ommand\x18\x02 \x03(\tB\x03\xe0\x41\x02R\x07\x63ommand\x12\x15\n\x03tty\x18\x03 \x01(\x08\x42\x03\xe0\x41\x01R\x03tty\x12 \n\ttty_width\x18\x04 \x01(\rB\x03\xe0\x41\x01R\x08ttyWidth\x12\"\n\ntty_height\x18\x05 \x01(\rB\x03\xe0\x41\x01R\tttyHeight\x12H\n\x03\x65nv\x18\x06 \x03(\x0b\x32\x31.coreweave.aviato.v1beta1.ExecStreamInit.EnvEntryB\x03\xe0\x41\x01R\x03\x65nv\x1a\x36\n\x08\x45nvEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\")\n\x0e\x45xecStreamData\x12\x17\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\x03\xe0\x41\x02R\x04\x64\x61ta\"J\n\x10\x45xecStreamResize\x12\x19\n\x05width\x18\x01 \x01(\rB\x03\xe0\x41\x02R\x05width\x12\x1b\n\x06height\x18\x02 \x01(\rB\x03\xe0\x41\x02R\x06height\"\x11\n\x0f\x45xecStreamClose\"P\n\x12StreamingExecReady\x12:\n\x08ready_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x07readyAt\"\xaf\x02\n\x12\x45xecStreamResponse\x12\x44\n\x06output\x18\x01 \x01(\x0b\x32*.coreweave.aviato.v1beta1.ExecStreamOutputH\x00R\x06output\x12>\n\x04\x65xit\x18\x02 \x01(\x0b\x32(.coreweave.aviato.v1beta1.ExecStreamExitH\x00R\x04\x65xit\x12\x41\n\x05\x65rror\x18\x03 \x01(\x0b\x32).coreweave.aviato.v1beta1.ExecStreamErrorH\x00R\x05\x65rror\x12\x44\n\x05ready\x18\x04 \x01(\x0b\x32,.coreweave.aviato.v1beta1.StreamingExecReadyH\x00R\x05readyB\n\n\x08response\"\xa2\x02\n\x10\x45xecStreamOutput\x12[\n\x0bstream_type\x18\x01 \x01(\x0e\x32\x35.coreweave.aviato.v1beta1.ExecStreamOutput.StreamTypeB\x03\xe0\x41\x02R\nstreamType\x12\x17\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x03\xe0\x41\x02R\x04\x64\x61ta\x12=\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ttimestamp\"Y\n\nStreamType\x12\x1b\n\x17STREAM_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12STREAM_TYPE_STDOUT\x10\x01\x12\x16\n\x12STREAM_TYPE_STDERR\x10\x02\"v\n\x0e\x45xecStreamExit\x12 \n\texit_code\x18\x01 \x01(\x05\x42\x03\xe0\x41\x02R\x08\x65xitCode\x12\x42\n\x0c\x63ompleted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x0b\x63ompletedAt\"I\n\x0f\x45xecStreamError\x12\x1d\n\x07message\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x07message\x12\x17\n\x04\x63ode\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04\x63ode\"\x9e\x01\n\x10LogStreamRequest\x12=\n\x04init\x18\x01 \x01(\x0b\x32\'.coreweave.aviato.v1beta1.LogStreamInitH\x00R\x04init\x12@\n\x05\x63lose\x18\x02 \x01(\x0b\x32(.coreweave.aviato.v1beta1.LogStreamCloseH\x00R\x05\x63loseB\t\n\x07request\"\xd9\x01\n\rLogStreamInit\x12\"\n\nsandbox_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tsandboxId\x12\x1b\n\x06\x66ollow\x18\x02 \x01(\x08\x42\x03\xe0\x41\x01R\x06\x66ollow\x12\"\n\ntail_lines\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01R\ttailLines\x12>\n\nsince_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x01R\tsinceTime\x12#\n\ntimestamps\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01R\ntimestamps\"\x10\n\x0eLogStreamClose\"\xeb\x01\n\x11LogStreamResponse\x12=\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\'.coreweave.aviato.v1beta1.LogStreamDataH\x00R\x04\x64\x61ta\x12@\n\x05\x65rror\x18\x02 \x01(\x0b\x32(.coreweave.aviato.v1beta1.LogStreamErrorH\x00R\x05\x65rror\x12I\n\x08\x63omplete\x18\x03 \x01(\x0b\x32+.coreweave.aviato.v1beta1.LogStreamCompleteH\x00R\x08\x63ompleteB\n\n\x08response\"g\n\rLogStreamData\x12\x17\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\x03\xe0\x41\x02R\x04\x64\x61ta\x12=\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x01R\ttimestamp\"\x13\n\x11LogStreamComplete\"H\n\x0eLogStreamError\x12\x1d\n\x07message\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x07message\x12\x17\n\x04\x63ode\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04\x63ode2\xf1\x01\n\x13\x41TCStreamingService\x12m\n\nStreamExec\x12+.coreweave.aviato.v1beta1.ExecStreamRequest\x1a,.coreweave.aviato.v1beta1.ExecStreamResponse\"\x00(\x01\x30\x01\x12k\n\nStreamLogs\x12*.coreweave.aviato.v1beta1.LogStreamRequest\x1a+.coreweave.aviato.v1beta1.LogStreamResponse\"\x00(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'coreweave.aviato.v1beta1.streaming_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EXECSTREAMINIT_ENVENTRY']._loaded_options = None
  _globals['_EXECSTREAMINIT_ENVENTRY']._serialized_options = b'8\001'
  _globals['_EXECSTREAMINIT'].fields_by_name['sandbox_id']._loaded_options = None
  _globals['_EXECSTREAMINIT'].fields_by_name['sandbox_id']._serialized_options = b'\340A\002'
  _globals['_EXECSTREAMINIT'].fields_by_name['command']._loaded_options = None
  _globals['_EXECSTREAMINIT'].fields_by_name['command']._serialized_options = b'\340A\002'
  _globals['_EXECSTREAMINIT'].fields_by_name['tty']._loaded_options = None
  _globals['_EXECSTREAMINIT'].fields_by_name['tty']._serialized_options = b'\340A\001'
  _globals['_EXECSTREAMINIT'].fields_by_name['tty_width']._loaded_options = None
  _globals['_EXECSTREAMINIT'].fields_by_name['tty_width']._serialized_options = b'\340A\001'
  _globals['_EXECSTREAMINIT'].fields_by_name['tty_height']._loaded_options = None
  _globals['_EXECSTREAMINIT'].fields_by_name['tty_height']._serialized_options = b'\340A\001'
  _globals['_EXECSTREAMINIT'].fields_by_name['env']._loaded_options = None
  _globals['_EXECSTREAMINIT'].fields_by_name['env']._serialized_options = b'\340A\001'
  _globals['_EXECSTREAMDATA'].fields_by_name['data']._loaded_options = None
  _globals['_EXECSTREAMDATA'].fields_by_name['data']._serialized_options = b'\340A\002'
  _globals['_EXECSTREAMRESIZE'].fields_by_name['width']._loaded_options = None
  _globals['_EXECSTREAMRESIZE'].fields_by_name['width']._serialized_options = b'\340A\002'
  _globals['_EXECSTREAMRESIZE'].fields_by_name['height']._loaded_options = None
  _globals['_EXECSTREAMRESIZE'].fields_by_name['height']._serialized_options = b'\340A\002'
  _globals['_STREAMINGEXECREADY'].fields_by_name['ready_at']._loaded_options = None
  _globals['_STREAMINGEXECREADY'].fields_by_name['ready_at']._serialized_options = b'\340A\003'
  _globals['_EXECSTREAMOUTPUT'].fields_by_name['stream_type']._loaded_options = None
  _globals['_EXECSTREAMOUTPUT'].fields_by_name['stream_type']._serialized_options = b'\340A\002'
  _globals['_EXECSTREAMOUTPUT'].fields_by_name['data']._loaded_options = None
  _globals['_EXECSTREAMOUTPUT'].fields_by_name['data']._serialized_options = b'\340A\002'
  _globals['_EXECSTREAMOUTPUT'].fields_by_name['timestamp']._loaded_options = None
  _globals['_EXECSTREAMOUTPUT'].fields_by_name['timestamp']._serialized_options = b'\340A\003'
  _globals['_EXECSTREAMEXIT'].fields_by_name['exit_code']._loaded_options = None
  _globals['_EXECSTREAMEXIT'].fields_by_name['exit_code']._serialized_options = b'\340A\002'
  _globals['_EXECSTREAMEXIT'].fields_by_name['completed_at']._loaded_options = None
  _globals['_EXECSTREAMEXIT'].fields_by_name['completed_at']._serialized_options = b'\340A\003'
  _globals['_EXECSTREAMERROR'].fields_by_name['message']._loaded_options = None
  _globals['_EXECSTREAMERROR'].fields_by_name['message']._serialized_options = b'\340A\002'
  _globals['_EXECSTREAMERROR'].fields_by_name['code']._loaded_options = None
  _globals['_EXECSTREAMERROR'].fields_by_name['code']._serialized_options = b'\340A\002'
  _globals['_LOGSTREAMINIT'].fields_by_name['sandbox_id']._loaded_options = None
  _globals['_LOGSTREAMINIT'].fields_by_name['sandbox_id']._serialized_options = b'\340A\002'
  _globals['_LOGSTREAMINIT'].fields_by_name['follow']._loaded_options = None
  _globals['_LOGSTREAMINIT'].fields_by_name['follow']._serialized_options = b'\340A\001'
  _globals['_LOGSTREAMINIT'].fields_by_name['tail_lines']._loaded_options = None
  _globals['_LOGSTREAMINIT'].fields_by_name['tail_lines']._serialized_options = b'\340A\001'
  _globals['_LOGSTREAMINIT'].fields_by_name['since_time']._loaded_options = None
  _globals['_LOGSTREAMINIT'].fields_by_name['since_time']._serialized_options = b'\340A\001'
  _globals['_LOGSTREAMINIT'].fields_by_name['timestamps']._loaded_options = None
  _globals['_LOGSTREAMINIT'].fields_by_name['timestamps']._serialized_options = b'\340A\001'
  _globals['_LOGSTREAMDATA'].fields_by_name['data']._loaded_options = None
  _globals['_LOGSTREAMDATA'].fields_by_name['data']._serialized_options = b'\340A\002'
  _globals['_LOGSTREAMDATA'].fields_by_name['timestamp']._loaded_options = None
  _globals['_LOGSTREAMDATA'].fields_by_name['timestamp']._serialized_options = b'\340A\001'
  _globals['_LOGSTREAMERROR'].fields_by_name['message']._loaded_options = None
  _globals['_LOGSTREAMERROR'].fields_by_name['message']._serialized_options = b'\340A\002'
  _globals['_LOGSTREAMERROR'].fields_by_name['code']._loaded_options = None
  _globals['_LOGSTREAMERROR'].fields_by_name['code']._serialized_options = b'\340A\002'
  _globals['_EXECSTREAMREQUEST']._serialized_start=137
  _globals['_EXECSTREAMREQUEST']._serialized_end=434
  _globals['_EXECSTREAMINIT']._serialized_start=437
  _globals['_EXECSTREAMINIT']._serialized_end=743
  _globals['_EXECSTREAMINIT_ENVENTRY']._serialized_start=689
  _globals['_EXECSTREAMINIT_ENVENTRY']._serialized_end=743
  _globals['_EXECSTREAMDATA']._serialized_start=745
  _globals['_EXECSTREAMDATA']._serialized_end=786
  _globals['_EXECSTREAMRESIZE']._serialized_start=788
  _globals['_EXECSTREAMRESIZE']._serialized_end=862
  _globals['_EXECSTREAMCLOSE']._serialized_start=864
  _globals['_EXECSTREAMCLOSE']._serialized_end=881
  _globals['_STREAMINGEXECREADY']._serialized_start=883
  _globals['_STREAMINGEXECREADY']._serialized_end=963
  _globals['_EXECSTREAMRESPONSE']._serialized_start=966
  _globals['_EXECSTREAMRESPONSE']._serialized_end=1269
  _globals['_EXECSTREAMOUTPUT']._serialized_start=1272
  _globals['_EXECSTREAMOUTPUT']._serialized_end=1562
  _globals['_EXECSTREAMOUTPUT_STREAMTYPE']._serialized_start=1473
  _globals['_EXECSTREAMOUTPUT_STREAMTYPE']._serialized_end=1562
  _globals['_EXECSTREAMEXIT']._serialized_start=1564
  _globals['_EXECSTREAMEXIT']._serialized_end=1682
  _globals['_EXECSTREAMERROR']._serialized_start=1684
  _globals['_EXECSTREAMERROR']._serialized_end=1757
  _globals['_LOGSTREAMREQUEST']._serialized_start=1760
  _globals['_LOGSTREAMREQUEST']._serialized_end=1918
  _globals['_LOGSTREAMINIT']._serialized_start=1921
  _globals['_LOGSTREAMINIT']._serialized_end=2138
  _globals['_LOGSTREAMCLOSE']._serialized_start=2140
  _globals['_LOGSTREAMCLOSE']._serialized_end=2156
  _globals['_LOGSTREAMRESPONSE']._serialized_start=2159
  _globals['_LOGSTREAMRESPONSE']._serialized_end=2394
  _globals['_LOGSTREAMDATA']._serialized_start=2396
  _globals['_LOGSTREAMDATA']._serialized_end=2499
  _globals['_LOGSTREAMCOMPLETE']._serialized_start=2501
  _globals['_LOGSTREAMCOMPLETE']._serialized_end=2520
  _globals['_LOGSTREAMERROR']._serialized_start=2522
  _globals['_LOGSTREAMERROR']._serialized_end=2594
  _globals['_ATCSTREAMINGSERVICE']._serialized_start=2597
  _globals['_ATCSTREAMINGSERVICE']._serialized_end=2838
# @@protoc_insertion_point(module_scope)
