# SPDX-FileCopyrightText: 2025 CoreWeave, Inc.
# SPDX-License-Identifier: Apache-2.0
# SPDX-PackageName: cwsandbox-client
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: coreweave/aviato/v1beta1/atc.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'coreweave/aviato/v1beta1/atc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cwsandbox._proto import secrets_pb2 as coreweave_dot_aviato_dot_v1beta1_dot_secrets__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"coreweave/aviato/v1beta1/atc.proto\x12\x18\x63oreweave.aviato.v1beta1\x1a&coreweave/aviato/v1beta1/secrets.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"Y\n\x0bMountedFile\x12\"\n\nmount_path\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tmountPath\x12&\n\x0c\x66ile_content\x18\x02 \x01(\x0c\x42\x03\xe0\x41\x02R\x0b\x66ileContent\"t\n\nGpuRequest\x12\x1b\n\tgpu_count\x18\x01 \x01(\x03R\x08gpuCount\x12\x1b\n\x08gpu_type\x18\x02 \x01(\tH\x00R\x07gpuType\x12$\n\rgpu_memory_gb\x18\x03 \x01(\x03H\x00R\x0bgpuMemoryGbB\x06\n\x04spec\"\x82\x01\n\x0fResourceRequest\x12\x15\n\x03\x63pu\x18\x01 \x01(\tB\x03\xe0\x41\x01R\x03\x63pu\x12\x1b\n\x06memory\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x06memory\x12;\n\x03gpu\x18\x03 \x01(\x0b\x32$.coreweave.aviato.v1beta1.GpuRequestB\x03\xe0\x41\x01R\x03gpu\"l\n\x04Port\x12*\n\x0e\x63ontainer_port\x18\x01 \x01(\x05\x42\x03\xe0\x41\x02R\rcontainerPort\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x04name\x12\x1f\n\x08protocol\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x08protocol\"9\n\rServiceConfig\x12(\n\rexposed_ports\x18\x01 \x03(\x05\x42\x03\xe0\x41\x02R\x0c\x65xposedPorts\"\x88\x01\n\x0eNetworkOptions\x12&\n\x0cingress_mode\x18\x01 \x01(\tB\x03\xe0\x41\x01R\x0bingressMode\x12(\n\rexposed_ports\x18\x02 \x03(\x05\x42\x03\xe0\x41\x01R\x0c\x65xposedPorts\x12$\n\x0b\x65gress_mode\x18\x03 \x01(\tB\x03\xe0\x41\x01R\negressMode\"b\n\x16KubernetesSecretSource\x12$\n\x0bsecret_name\x18\x01 \x01(\tB\x03\xe0\x41\x02R\nsecretName\x12\"\n\nsecret_key\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tsecretKey\"\x9f\x01\n\x1bTowerClusterSecretReference\x12R\n\nkubernetes\x18\x01 \x01(\x0b\x32\x30.coreweave.aviato.v1beta1.KubernetesSecretSourceH\x00R\nkubernetes\x12\x1c\n\x07\x65nv_var\x18\n \x01(\tB\x03\xe0\x41\x02R\x06\x65nvVarB\x08\n\x06sourceJ\x04\x08\x02\x10\n\"m\n\x07S3Mount\x12\x1b\n\x06\x62ucket\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x06\x62ucket\x12!\n\tdirectory\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tdirectory\x12\"\n\nmount_path\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tmountPath\"E\n\x0b\x45xecPayload\x12\x1d\n\x07\x63ommand\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x07\x63ommand\x12\x17\n\x04\x61rgs\x18\x02 \x03(\tB\x03\xe0\x41\x01R\x04\x61rgs\"[\n\x0c\x45xecResponse\x12\x16\n\x06stdout\x18\x01 \x01(\x0cR\x06stdout\x12\x16\n\x06stderr\x18\x02 \x01(\x0cR\x06stderr\x12\x1b\n\texit_code\x18\x03 \x01(\x05R\x08\x65xitCode\"\x8b\x01\n\rResourceUsage\x12.\n\x13\x63pu_millicores_used\x18\x01 \x01(\x03R\x11\x63puMillicoresUsed\x12$\n\x0ememory_mb_used\x18\x02 \x01(\x03R\x0cmemoryMbUsed\x12$\n\x0egpu_count_used\x18\x03 \x01(\x03R\x0cgpuCountUsed\"\x82\x01\n\x13ObjectStorageAccess\x12\x18\n\x07\x62uckets\x18\x01 \x03(\tR\x07\x62uckets\x12Q\n\npermission\x18\x02 \x01(\x0e\x32\x31.coreweave.aviato.v1beta1.ObjectStoragePermissionR\npermission\"\xdf\n\n\x13StartSandboxRequest\x12\x1d\n\x07\x63ommand\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x07\x63ommand\x12\x17\n\x04\x61rgs\x18\x02 \x03(\tB\x03\xe0\x41\x01R\x04\x61rgs\x12\x17\n\x04tags\x18\x03 \x03(\tB\x03\xe0\x41\x01R\x04tags\x12L\n\tresources\x18\x04 \x01(\x0b\x32).coreweave.aviato.v1beta1.ResourceRequestB\x03\xe0\x41\x01R\tresources\x12,\n\x0f\x63ontainer_image\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x0e\x63ontainerImage\x12\x81\x01\n\x15\x65nvironment_variables\x18\x06 \x03(\x0b\x32G.coreweave.aviato.v1beta1.StartSandboxRequest.EnvironmentVariablesEntryB\x03\xe0\x41\x01R\x14\x65nvironmentVariables\x12\x39\n\x05ports\x18\x07 \x03(\x0b\x32\x1e.coreweave.aviato.v1beta1.PortB\x03\xe0\x41\x01R\x05ports\x12O\n\rmounted_files\x18\x08 \x03(\x0b\x32%.coreweave.aviato.v1beta1.MountedFileB\x03\xe0\x41\x01R\x0cmountedFiles\x12\x41\n\x08s3_mount\x18\t \x01(\x0b\x32!.coreweave.aviato.v1beta1.S3MountB\x03\xe0\x41\x01R\x07s3Mount\x12G\n\x07network\x18\n \x01(\x0b\x32(.coreweave.aviato.v1beta1.NetworkOptionsB\x03\xe0\x41\x01R\x07network\x12\"\n\nrunway_ids\x18\x14 \x03(\tB\x03\xe0\x41\x01R\trunwayIds\x12 \n\ttower_ids\x18\x15 \x03(\tB\x03\xe0\x41\x01R\x08towerIds\x12\x35\n\x14max_lifetime_seconds\x18\x16 \x01(\x05\x42\x03\xe0\x41\x01R\x12maxLifetimeSeconds\x12\x33\n\x13max_timeout_seconds\x18\x17 \x01(\x05\x42\x03\xe0\x41\x01R\x11maxTimeoutSeconds\x12n\n\x15tower_cluster_secrets\x18\x18 \x03(\x0b\x32\x35.coreweave.aviato.v1beta1.TowerClusterSecretReferenceB\x03\xe0\x41\x01R\x13towerClusterSecrets\x12\x66\n\x15object_storage_access\x18\x19 \x01(\x0b\x32-.coreweave.aviato.v1beta1.ObjectStorageAccessB\x03\xe0\x41\x01R\x13objectStorageAccess\x12o\n\x0fpod_annotations\x18\x1a \x03(\x0b\x32\x41.coreweave.aviato.v1beta1.StartSandboxRequest.PodAnnotationsEntryB\x03\xe0\x41\x01R\x0epodAnnotations\x12X\n\rsecret_stores\x18\x1e \x03(\x0b\x32..coreweave.aviato.v1beta1.SecretStoreReferenceB\x03\xe0\x41\x01R\x0csecretStores\x1aG\n\x19\x45nvironmentVariablesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x41\n\x13PodAnnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xad\x04\n\x14StartSandboxResponse\x12\x1d\n\nsandbox_id\x18\x01 \x01(\tR\tsandboxId\x12\x42\n\x0fstarted_at_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rstartedAtTime\x12\'\n\x0fservice_address\x18\x03 \x01(\tR\x0eserviceAddress\x12\x43\n\rexposed_ports\x18\x04 \x03(\x0b\x32\x1e.coreweave.aviato.v1beta1.PortR\x0c\x65xposedPorts\x12Z\n\x13requested_resources\x18\x05 \x01(\x0b\x32).coreweave.aviato.v1beta1.ResourceRequestR\x12requestedResources\x12\x1b\n\trunway_id\x18\x06 \x01(\tR\x08runwayId\x12\x19\n\x08tower_id\x18\x07 \x01(\tR\x07towerId\x12N\n\x0esandbox_status\x18\x08 \x01(\x0e\x32\'.coreweave.aviato.v1beta1.SandboxStatusR\rsandboxStatus\x12\x30\n\x14\x61pplied_ingress_mode\x18\t \x01(\tR\x12\x61ppliedIngressMode\x12.\n\x13\x61pplied_egress_mode\x18\n \x01(\tR\x11\x61ppliedEgressMode\"\xdd\x01\n\x12StopSandboxRequest\x12\"\n\nsandbox_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tsandboxId\x12?\n\x19graceful_shutdown_seconds\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01R\x17gracefulShutdownSeconds\x12-\n\x10snapshot_on_stop\x18\x03 \x01(\x08\x42\x03\xe0\x41\x01R\x0esnapshotOnStop\x12\x33\n\x13max_timeout_seconds\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01R\x11maxTimeoutSeconds\"T\n\x13StopSandboxResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"l\n\x11GetSandboxRequest\x12\"\n\nsandbox_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tsandboxId\x12\x33\n\x13max_timeout_seconds\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01R\x11maxTimeoutSeconds\"\xd4\x04\n\x12GetSandboxResponse\x12\x1d\n\nsandbox_id\x18\x01 \x01(\tR\tsandboxId\x12\x42\n\x0fstarted_at_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rstartedAtTime\x12N\n\x0esandbox_status\x18\x03 \x01(\x0e\x32\'.coreweave.aviato.v1beta1.SandboxStatusR\rsandboxStatus\x12]\n\x16\x63urrent_resource_usage\x18\x04 \x01(\x0b\x32\'.coreweave.aviato.v1beta1.ResourceUsageR\x14\x63urrentResourceUsage\x12\x19\n\x08tower_id\x18\x05 \x01(\tR\x07towerId\x12$\n\x0etower_group_id\x18\x06 \x01(\tR\x0ctowerGroupId\x12\x1b\n\trunway_id\x18\x07 \x01(\tR\x08runwayId\x12\'\n\x0fservice_address\x18\x08 \x01(\tR\x0eserviceAddress\x12\x43\n\rexposed_ports\x18\t \x03(\x0b\x32\x1e.coreweave.aviato.v1beta1.PortR\x0c\x65xposedPorts\x12\x30\n\x14\x61pplied_ingress_mode\x18\n \x01(\tR\x12\x61ppliedIngressMode\x12.\n\x13\x61pplied_egress_mode\x18\x0b \x01(\tR\x11\x61ppliedEgressMode\"\x9e\x02\n\x14ListSandboxesRequest\x12\x17\n\x04tags\x18\x01 \x03(\tB\x03\xe0\x41\x01R\x04tags\x12\x44\n\x06status\x18\x02 \x01(\x0e\x32\'.coreweave.aviato.v1beta1.SandboxStatusB\x03\xe0\x41\x01R\x06status\x12\"\n\nrunway_ids\x18\x03 \x03(\tB\x03\xe0\x41\x01R\trunwayIds\x12 \n\ttower_ids\x18\x04 \x03(\tB\x03\xe0\x41\x01R\x08towerIds\x12\x33\n\x13max_timeout_seconds\x18\x05 \x01(\x05\x42\x03\xe0\x41\x01R\x11maxTimeoutSeconds\x12,\n\x0finclude_stopped\x18\x06 \x01(\x08\x42\x03\xe0\x41\x01R\x0eincludeStopped\"\\\n\x15ListSandboxesResponse\x12\x43\n\tsandboxes\x18\x01 \x03(\x0b\x32%.coreweave.aviato.v1beta1.SandboxInfoR\tsandboxes\"\xcd\x04\n\x0bSandboxInfo\x12\x1d\n\nsandbox_id\x18\x01 \x01(\tR\tsandboxId\x12\x42\n\x0fstarted_at_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rstartedAtTime\x12N\n\x0esandbox_status\x18\x03 \x01(\x0e\x32\'.coreweave.aviato.v1beta1.SandboxStatusR\rsandboxStatus\x12]\n\x16\x63urrent_resource_usage\x18\x04 \x01(\x0b\x32\'.coreweave.aviato.v1beta1.ResourceUsageR\x14\x63urrentResourceUsage\x12\x19\n\x08tower_id\x18\x05 \x01(\tR\x07towerId\x12$\n\x0etower_group_id\x18\x06 \x01(\tR\x0ctowerGroupId\x12\x1b\n\trunway_id\x18\x07 \x01(\tR\x08runwayId\x12\'\n\x0fservice_address\x18\x08 \x01(\tR\x0eserviceAddress\x12\x43\n\rexposed_ports\x18\t \x03(\x0b\x32\x1e.coreweave.aviato.v1beta1.PortR\x0c\x65xposedPorts\x12\x30\n\x14\x61pplied_ingress_mode\x18\n \x01(\tR\x12\x61ppliedIngressMode\x12.\n\x13\x61pplied_egress_mode\x18\x0b \x01(\tR\x11\x61ppliedEgressMode\"o\n\x14\x44\x65leteSandboxRequest\x12\"\n\nsandbox_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tsandboxId\x12\x33\n\x13max_timeout_seconds\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01R\x11maxTimeoutSeconds\"V\n\x15\x44\x65leteSandboxResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"\xa5\x01\n\x12\x45xecSandboxRequest\x12\"\n\nsandbox_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tsandboxId\x12\x1d\n\x07\x63ommand\x18\x02 \x03(\tB\x03\xe0\x41\x02R\x07\x63ommand\x12\x17\n\x04\x61rgs\x18\x03 \x03(\tB\x03\xe0\x41\x01R\x04\x61rgs\x12\x33\n\x13max_timeout_seconds\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01R\x11maxTimeoutSeconds\"U\n\x13\x45xecSandboxResponse\x12>\n\x06result\x18\x01 \x01(\x0b\x32&.coreweave.aviato.v1beta1.ExecResponseR\x06result\"\xbb\x01\n\x15\x41\x64\x64\x46ileSandboxRequest\x12\"\n\nsandbox_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tsandboxId\x12(\n\rfile_contents\x18\x02 \x01(\x0c\x42\x03\xe0\x41\x02R\x0c\x66ileContents\x12\x1f\n\x08\x66ilepath\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x66ilepath\x12\x33\n\x13max_timeout_seconds\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01R\x11maxTimeoutSeconds\"W\n\x16\x41\x64\x64\x46ileSandboxResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"\x96\x01\n\x1aRetrieveFileSandboxRequest\x12\"\n\nsandbox_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tsandboxId\x12\x1f\n\x08\x66ilepath\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x66ilepath\x12\x33\n\x13max_timeout_seconds\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01R\x11maxTimeoutSeconds\"\x81\x01\n\x1bRetrieveFileSandboxResponse\x12#\n\rfile_contents\x18\x01 \x01(\x0cR\x0c\x66ileContents\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\"n\n\x13PauseSandboxRequest\x12\"\n\nsandbox_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tsandboxId\x12\x33\n\x13max_timeout_seconds\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01R\x11maxTimeoutSeconds\"U\n\x14PauseSandboxResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"o\n\x14ResumeSandboxRequest\x12\"\n\nsandbox_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tsandboxId\x12\x33\n\x13max_timeout_seconds\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01R\x11maxTimeoutSeconds\"V\n\x15ResumeSandboxResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"\xdf\x03\n\x11RawSandboxRequest\x12\"\n\nsandbox_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tsandboxId\x12J\n\x0b\x61\x63tion_type\x18\x02 \x01(\x0e\x32$.coreweave.aviato.v1beta1.ActionTypeB\x03\xe0\x41\x02R\nactionType\x12J\n\x0c\x65xec_payload\x18\x03 \x01(\x0b\x32%.coreweave.aviato.v1beta1.ExecPayloadH\x00R\x0b\x65xecPayload\x12[\n\x10\x61\x64\x64_file_payload\x18\x04 \x01(\x0b\x32/.coreweave.aviato.v1beta1.AddFileSandboxRequestH\x00R\x0e\x61\x64\x64\x46ilePayload\x12j\n\x15retrieve_file_payload\x18\x05 \x01(\x0b\x32\x34.coreweave.aviato.v1beta1.RetrieveFileSandboxRequestH\x00R\x13retrieveFilePayload\x12\x33\n\x13max_timeout_seconds\x18\x06 \x01(\x05\x42\x03\xe0\x41\x01R\x11maxTimeoutSecondsB\x10\n\x0e\x61\x63tion_payload\"\x93\x03\n\x12RawSandboxResponse\x12\x45\n\x0b\x61\x63tion_type\x18\x01 \x01(\x0e\x32$.coreweave.aviato.v1beta1.ActionTypeR\nactionType\x12T\n\rexec_response\x18\x02 \x01(\x0b\x32-.coreweave.aviato.v1beta1.ExecSandboxResponseH\x00R\x0c\x65xecResponse\x12^\n\x11\x61\x64\x64_file_response\x18\x03 \x01(\x0b\x32\x30.coreweave.aviato.v1beta1.AddFileSandboxResponseH\x00R\x0f\x61\x64\x64\x46ileResponse\x12m\n\x16retrieve_file_response\x18\x04 \x01(\x0b\x32\x35.coreweave.aviato.v1beta1.RetrieveFileSandboxResponseH\x00R\x14retrieveFileResponseB\x11\n\x0f\x61\x63tion_response*\xf7\x01\n\rSandboxStatus\x12\x1e\n\x1aSANDBOX_STATUS_UNSPECIFIED\x10\x00\x12\x1b\n\x17SANDBOX_STATUS_CREATING\x10\x01\x12\x1a\n\x16SANDBOX_STATUS_RUNNING\x10\x02\x12\x1c\n\x18SANDBOX_STATUS_COMPLETED\x10\x03\x12\x19\n\x15SANDBOX_STATUS_FAILED\x10\x04\x12\x1d\n\x19SANDBOX_STATUS_TERMINATED\x10\x05\x12\x1a\n\x16SANDBOX_STATUS_PENDING\x10\x06\x12\x19\n\x15SANDBOX_STATUS_PAUSED\x10\x07*\xf3\x01\n\nActionType\x12\x1b\n\x17\x41\x43TION_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41\x43TION_TYPE_EXEC\x10\x01\x12\x18\n\x14\x41\x43TION_TYPE_ADD_FILE\x10\x02\x12\x1d\n\x19\x41\x43TION_TYPE_RETRIEVE_FILE\x10\x03\x12\x18\n\x14\x41\x43TION_TYPE_GET_LOGS\x10\x04\x12\x18\n\x14\x41\x43TION_TYPE_SNAPSHOT\x10\x05\x12\x17\n\x13\x41\x43TION_TYPE_RESTORE\x10\x06\x12\x16\n\x12\x41\x43TION_TYPE_STATUS\x10\x07\x12\x14\n\x10\x41\x43TION_TYPE_STOP\x10\x08*\xb7\x01\n\nEgressType\x12\x1b\n\x17\x45GRESS_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45GRESS_TYPE_NONE\x10\x01\x12\x18\n\x14\x45GRESS_TYPE_INTERNET\x10\x02\x12\x14\n\x10\x45GRESS_TYPE_USER\x10\x03\x12\x13\n\x0f\x45GRESS_TYPE_ORG\x10\x04\x12\x16\n\x12\x45GRESS_TYPE_RUNWAY\x10\x05\x12\x19\n\x15\x45GRESS_TYPE_ALLOWLIST\x10\x06*\x92\x01\n\x17ObjectStoragePermission\x12)\n%OBJECT_STORAGE_PERMISSION_UNSPECIFIED\x10\x00\x12\"\n\x1eOBJECT_STORAGE_PERMISSION_READ\x10\x01\x12(\n$OBJECT_STORAGE_PERMISSION_READ_WRITE\x10\x02\x32\x8f\r\n\nATCService\x12\x85\x01\n\x05Start\x12-.coreweave.aviato.v1beta1.StartSandboxRequest\x1a..coreweave.aviato.v1beta1.StartSandboxResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1beta1/sandboxes:\x01*\x12\x94\x01\n\x04Stop\x12,.coreweave.aviato.v1beta1.StopSandboxRequest\x1a-.coreweave.aviato.v1beta1.StopSandboxResponse\"/\x82\xd3\xe4\x93\x02)\"$/v1beta1/sandboxes/{sandbox_id}/stop:\x01*\x12\x89\x01\n\x03Get\x12+.coreweave.aviato.v1beta1.GetSandboxRequest\x1a,.coreweave.aviato.v1beta1.GetSandboxResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1beta1/sandboxes/{sandbox_id}\x12\x83\x01\n\x04List\x12..coreweave.aviato.v1beta1.ListSandboxesRequest\x1a/.coreweave.aviato.v1beta1.ListSandboxesResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1beta1/sandboxes\x12\x92\x01\n\x06\x44\x65lete\x12..coreweave.aviato.v1beta1.DeleteSandboxRequest\x1a/.coreweave.aviato.v1beta1.DeleteSandboxResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1beta1/sandboxes/{sandbox_id}\x12\x94\x01\n\x04\x45xec\x12,.coreweave.aviato.v1beta1.ExecSandboxRequest\x1a-.coreweave.aviato.v1beta1.ExecSandboxResponse\"/\x82\xd3\xe4\x93\x02)\"$/v1beta1/sandboxes/{sandbox_id}/exec:\x01*\x12\x9e\x01\n\x07\x41\x64\x64\x46ile\x12/.coreweave.aviato.v1beta1.AddFileSandboxRequest\x1a\x30.coreweave.aviato.v1beta1.AddFileSandboxResponse\"0\x82\xd3\xe4\x93\x02*\"%/v1beta1/sandboxes/{sandbox_id}/files:\x01*\x12\xb5\x01\n\x0cRetrieveFile\x12\x34.coreweave.aviato.v1beta1.RetrieveFileSandboxRequest\x1a\x35.coreweave.aviato.v1beta1.RetrieveFileSandboxResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v1beta1/sandboxes/{sandbox_id}/files/{filepath}\x12\x98\x01\n\x05Pause\x12-.coreweave.aviato.v1beta1.PauseSandboxRequest\x1a..coreweave.aviato.v1beta1.PauseSandboxResponse\"0\x82\xd3\xe4\x93\x02*\"%/v1beta1/sandboxes/{sandbox_id}/pause:\x01*\x12\x9c\x01\n\x06Resume\x12..coreweave.aviato.v1beta1.ResumeSandboxRequest\x1a/.coreweave.aviato.v1beta1.ResumeSandboxResponse\"1\x82\xd3\xe4\x93\x02+\"&/v1beta1/sandboxes/{sandbox_id}/resume:\x01*\x12\x90\x01\n\x03Raw\x12+.coreweave.aviato.v1beta1.RawSandboxRequest\x1a,.coreweave.aviato.v1beta1.RawSandboxResponse\".\x82\xd3\xe4\x93\x02(\"#/v1beta1/sandboxes/{sandbox_id}/raw:\x01*b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'coreweave.aviato.v1beta1.atc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MOUNTEDFILE'].fields_by_name['mount_path']._loaded_options = None
  _globals['_MOUNTEDFILE'].fields_by_name['mount_path']._serialized_options = b'\340A\002'
  _globals['_MOUNTEDFILE'].fields_by_name['file_content']._loaded_options = None
  _globals['_MOUNTEDFILE'].fields_by_name['file_content']._serialized_options = b'\340A\002'
  _globals['_RESOURCEREQUEST'].fields_by_name['cpu']._loaded_options = None
  _globals['_RESOURCEREQUEST'].fields_by_name['cpu']._serialized_options = b'\340A\001'
  _globals['_RESOURCEREQUEST'].fields_by_name['memory']._loaded_options = None
  _globals['_RESOURCEREQUEST'].fields_by_name['memory']._serialized_options = b'\340A\001'
  _globals['_RESOURCEREQUEST'].fields_by_name['gpu']._loaded_options = None
  _globals['_RESOURCEREQUEST'].fields_by_name['gpu']._serialized_options = b'\340A\001'
  _globals['_PORT'].fields_by_name['container_port']._loaded_options = None
  _globals['_PORT'].fields_by_name['container_port']._serialized_options = b'\340A\002'
  _globals['_PORT'].fields_by_name['name']._loaded_options = None
  _globals['_PORT'].fields_by_name['name']._serialized_options = b'\340A\001'
  _globals['_PORT'].fields_by_name['protocol']._loaded_options = None
  _globals['_PORT'].fields_by_name['protocol']._serialized_options = b'\340A\001'
  _globals['_SERVICECONFIG'].fields_by_name['exposed_ports']._loaded_options = None
  _globals['_SERVICECONFIG'].fields_by_name['exposed_ports']._serialized_options = b'\340A\002'
  _globals['_NETWORKOPTIONS'].fields_by_name['ingress_mode']._loaded_options = None
  _globals['_NETWORKOPTIONS'].fields_by_name['ingress_mode']._serialized_options = b'\340A\001'
  _globals['_NETWORKOPTIONS'].fields_by_name['exposed_ports']._loaded_options = None
  _globals['_NETWORKOPTIONS'].fields_by_name['exposed_ports']._serialized_options = b'\340A\001'
  _globals['_NETWORKOPTIONS'].fields_by_name['egress_mode']._loaded_options = None
  _globals['_NETWORKOPTIONS'].fields_by_name['egress_mode']._serialized_options = b'\340A\001'
  _globals['_KUBERNETESSECRETSOURCE'].fields_by_name['secret_name']._loaded_options = None
  _globals['_KUBERNETESSECRETSOURCE'].fields_by_name['secret_name']._serialized_options = b'\340A\002'
  _globals['_KUBERNETESSECRETSOURCE'].fields_by_name['secret_key']._loaded_options = None
  _globals['_KUBERNETESSECRETSOURCE'].fields_by_name['secret_key']._serialized_options = b'\340A\002'
  _globals['_TOWERCLUSTERSECRETREFERENCE'].fields_by_name['env_var']._loaded_options = None
  _globals['_TOWERCLUSTERSECRETREFERENCE'].fields_by_name['env_var']._serialized_options = b'\340A\002'
  _globals['_S3MOUNT'].fields_by_name['bucket']._loaded_options = None
  _globals['_S3MOUNT'].fields_by_name['bucket']._serialized_options = b'\340A\002'
  _globals['_S3MOUNT'].fields_by_name['directory']._loaded_options = None
  _globals['_S3MOUNT'].fields_by_name['directory']._serialized_options = b'\340A\002'
  _globals['_S3MOUNT'].fields_by_name['mount_path']._loaded_options = None
  _globals['_S3MOUNT'].fields_by_name['mount_path']._serialized_options = b'\340A\002'
  _globals['_EXECPAYLOAD'].fields_by_name['command']._loaded_options = None
  _globals['_EXECPAYLOAD'].fields_by_name['command']._serialized_options = b'\340A\002'
  _globals['_EXECPAYLOAD'].fields_by_name['args']._loaded_options = None
  _globals['_EXECPAYLOAD'].fields_by_name['args']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST_ENVIRONMENTVARIABLESENTRY']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST_ENVIRONMENTVARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_STARTSANDBOXREQUEST_PODANNOTATIONSENTRY']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST_PODANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['command']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['command']._serialized_options = b'\340A\002'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['args']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['args']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['tags']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['tags']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['resources']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['resources']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['container_image']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['container_image']._serialized_options = b'\340A\002'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['environment_variables']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['environment_variables']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['ports']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['ports']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['mounted_files']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['mounted_files']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['s3_mount']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['s3_mount']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['network']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['network']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['runway_ids']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['runway_ids']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['tower_ids']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['tower_ids']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['max_lifetime_seconds']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['max_lifetime_seconds']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['tower_cluster_secrets']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['tower_cluster_secrets']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['object_storage_access']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['object_storage_access']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['pod_annotations']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['pod_annotations']._serialized_options = b'\340A\001'
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['secret_stores']._loaded_options = None
  _globals['_STARTSANDBOXREQUEST'].fields_by_name['secret_stores']._serialized_options = b'\340A\001'
  _globals['_STOPSANDBOXREQUEST'].fields_by_name['sandbox_id']._loaded_options = None
  _globals['_STOPSANDBOXREQUEST'].fields_by_name['sandbox_id']._serialized_options = b'\340A\002'
  _globals['_STOPSANDBOXREQUEST'].fields_by_name['graceful_shutdown_seconds']._loaded_options = None
  _globals['_STOPSANDBOXREQUEST'].fields_by_name['graceful_shutdown_seconds']._serialized_options = b'\340A\001'
  _globals['_STOPSANDBOXREQUEST'].fields_by_name['snapshot_on_stop']._loaded_options = None
  _globals['_STOPSANDBOXREQUEST'].fields_by_name['snapshot_on_stop']._serialized_options = b'\340A\001'
  _globals['_STOPSANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._loaded_options = None
  _globals['_STOPSANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._serialized_options = b'\340A\001'
  _globals['_GETSANDBOXREQUEST'].fields_by_name['sandbox_id']._loaded_options = None
  _globals['_GETSANDBOXREQUEST'].fields_by_name['sandbox_id']._serialized_options = b'\340A\002'
  _globals['_GETSANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._loaded_options = None
  _globals['_GETSANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._serialized_options = b'\340A\001'
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['tags']._loaded_options = None
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['tags']._serialized_options = b'\340A\001'
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['status']._loaded_options = None
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['status']._serialized_options = b'\340A\001'
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['runway_ids']._loaded_options = None
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['runway_ids']._serialized_options = b'\340A\001'
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['tower_ids']._loaded_options = None
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['tower_ids']._serialized_options = b'\340A\001'
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['max_timeout_seconds']._loaded_options = None
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['max_timeout_seconds']._serialized_options = b'\340A\001'
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['include_stopped']._loaded_options = None
  _globals['_LISTSANDBOXESREQUEST'].fields_by_name['include_stopped']._serialized_options = b'\340A\001'
  _globals['_DELETESANDBOXREQUEST'].fields_by_name['sandbox_id']._loaded_options = None
  _globals['_DELETESANDBOXREQUEST'].fields_by_name['sandbox_id']._serialized_options = b'\340A\002'
  _globals['_DELETESANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._loaded_options = None
  _globals['_DELETESANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._serialized_options = b'\340A\001'
  _globals['_EXECSANDBOXREQUEST'].fields_by_name['sandbox_id']._loaded_options = None
  _globals['_EXECSANDBOXREQUEST'].fields_by_name['sandbox_id']._serialized_options = b'\340A\002'
  _globals['_EXECSANDBOXREQUEST'].fields_by_name['command']._loaded_options = None
  _globals['_EXECSANDBOXREQUEST'].fields_by_name['command']._serialized_options = b'\340A\002'
  _globals['_EXECSANDBOXREQUEST'].fields_by_name['args']._loaded_options = None
  _globals['_EXECSANDBOXREQUEST'].fields_by_name['args']._serialized_options = b'\340A\001'
  _globals['_EXECSANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._loaded_options = None
  _globals['_EXECSANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._serialized_options = b'\340A\001'
  _globals['_ADDFILESANDBOXREQUEST'].fields_by_name['sandbox_id']._loaded_options = None
  _globals['_ADDFILESANDBOXREQUEST'].fields_by_name['sandbox_id']._serialized_options = b'\340A\002'
  _globals['_ADDFILESANDBOXREQUEST'].fields_by_name['file_contents']._loaded_options = None
  _globals['_ADDFILESANDBOXREQUEST'].fields_by_name['file_contents']._serialized_options = b'\340A\002'
  _globals['_ADDFILESANDBOXREQUEST'].fields_by_name['filepath']._loaded_options = None
  _globals['_ADDFILESANDBOXREQUEST'].fields_by_name['filepath']._serialized_options = b'\340A\002'
  _globals['_ADDFILESANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._loaded_options = None
  _globals['_ADDFILESANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._serialized_options = b'\340A\001'
  _globals['_RETRIEVEFILESANDBOXREQUEST'].fields_by_name['sandbox_id']._loaded_options = None
  _globals['_RETRIEVEFILESANDBOXREQUEST'].fields_by_name['sandbox_id']._serialized_options = b'\340A\002'
  _globals['_RETRIEVEFILESANDBOXREQUEST'].fields_by_name['filepath']._loaded_options = None
  _globals['_RETRIEVEFILESANDBOXREQUEST'].fields_by_name['filepath']._serialized_options = b'\340A\002'
  _globals['_RETRIEVEFILESANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._loaded_options = None
  _globals['_RETRIEVEFILESANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._serialized_options = b'\340A\001'
  _globals['_PAUSESANDBOXREQUEST'].fields_by_name['sandbox_id']._loaded_options = None
  _globals['_PAUSESANDBOXREQUEST'].fields_by_name['sandbox_id']._serialized_options = b'\340A\002'
  _globals['_PAUSESANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._loaded_options = None
  _globals['_PAUSESANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._serialized_options = b'\340A\001'
  _globals['_RESUMESANDBOXREQUEST'].fields_by_name['sandbox_id']._loaded_options = None
  _globals['_RESUMESANDBOXREQUEST'].fields_by_name['sandbox_id']._serialized_options = b'\340A\002'
  _globals['_RESUMESANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._loaded_options = None
  _globals['_RESUMESANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._serialized_options = b'\340A\001'
  _globals['_RAWSANDBOXREQUEST'].fields_by_name['sandbox_id']._loaded_options = None
  _globals['_RAWSANDBOXREQUEST'].fields_by_name['sandbox_id']._serialized_options = b'\340A\002'
  _globals['_RAWSANDBOXREQUEST'].fields_by_name['action_type']._loaded_options = None
  _globals['_RAWSANDBOXREQUEST'].fields_by_name['action_type']._serialized_options = b'\340A\002'
  _globals['_RAWSANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._loaded_options = None
  _globals['_RAWSANDBOXREQUEST'].fields_by_name['max_timeout_seconds']._serialized_options = b'\340A\001'
  _globals['_ATCSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_ATCSERVICE'].methods_by_name['Start']._serialized_options = b'\202\323\344\223\002\027\"\022/v1beta1/sandboxes:\001*'
  _globals['_ATCSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_ATCSERVICE'].methods_by_name['Stop']._serialized_options = b'\202\323\344\223\002)\"$/v1beta1/sandboxes/{sandbox_id}/stop:\001*'
  _globals['_ATCSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_ATCSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/v1beta1/sandboxes/{sandbox_id}'
  _globals['_ATCSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ATCSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\024\022\022/v1beta1/sandboxes'
  _globals['_ATCSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_ATCSERVICE'].methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002!*\037/v1beta1/sandboxes/{sandbox_id}'
  _globals['_ATCSERVICE'].methods_by_name['Exec']._loaded_options = None
  _globals['_ATCSERVICE'].methods_by_name['Exec']._serialized_options = b'\202\323\344\223\002)\"$/v1beta1/sandboxes/{sandbox_id}/exec:\001*'
  _globals['_ATCSERVICE'].methods_by_name['AddFile']._loaded_options = None
  _globals['_ATCSERVICE'].methods_by_name['AddFile']._serialized_options = b'\202\323\344\223\002*\"%/v1beta1/sandboxes/{sandbox_id}/files:\001*'
  _globals['_ATCSERVICE'].methods_by_name['RetrieveFile']._loaded_options = None
  _globals['_ATCSERVICE'].methods_by_name['RetrieveFile']._serialized_options = b'\202\323\344\223\0022\0220/v1beta1/sandboxes/{sandbox_id}/files/{filepath}'
  _globals['_ATCSERVICE'].methods_by_name['Pause']._loaded_options = None
  _globals['_ATCSERVICE'].methods_by_name['Pause']._serialized_options = b'\202\323\344\223\002*\"%/v1beta1/sandboxes/{sandbox_id}/pause:\001*'
  _globals['_ATCSERVICE'].methods_by_name['Resume']._loaded_options = None
  _globals['_ATCSERVICE'].methods_by_name['Resume']._serialized_options = b'\202\323\344\223\002+\"&/v1beta1/sandboxes/{sandbox_id}/resume:\001*'
  _globals['_ATCSERVICE'].methods_by_name['Raw']._loaded_options = None
  _globals['_ATCSERVICE'].methods_by_name['Raw']._serialized_options = b'\202\323\344\223\002(\"#/v1beta1/sandboxes/{sandbox_id}/raw:\001*'
  _globals['_SANDBOXSTATUS']._serialized_start=7903
  _globals['_SANDBOXSTATUS']._serialized_end=8150
  _globals['_ACTIONTYPE']._serialized_start=8153
  _globals['_ACTIONTYPE']._serialized_end=8396
  _globals['_EGRESSTYPE']._serialized_start=8399
  _globals['_EGRESSTYPE']._serialized_end=8582
  _globals['_OBJECTSTORAGEPERMISSION']._serialized_start=8585
  _globals['_OBJECTSTORAGEPERMISSION']._serialized_end=8731
  _globals['_MOUNTEDFILE']._serialized_start=200
  _globals['_MOUNTEDFILE']._serialized_end=289
  _globals['_GPUREQUEST']._serialized_start=291
  _globals['_GPUREQUEST']._serialized_end=407
  _globals['_RESOURCEREQUEST']._serialized_start=410
  _globals['_RESOURCEREQUEST']._serialized_end=540
  _globals['_PORT']._serialized_start=542
  _globals['_PORT']._serialized_end=650
  _globals['_SERVICECONFIG']._serialized_start=652
  _globals['_SERVICECONFIG']._serialized_end=709
  _globals['_NETWORKOPTIONS']._serialized_start=712
  _globals['_NETWORKOPTIONS']._serialized_end=848
  _globals['_KUBERNETESSECRETSOURCE']._serialized_start=850
  _globals['_KUBERNETESSECRETSOURCE']._serialized_end=948
  _globals['_TOWERCLUSTERSECRETREFERENCE']._serialized_start=951
  _globals['_TOWERCLUSTERSECRETREFERENCE']._serialized_end=1110
  _globals['_S3MOUNT']._serialized_start=1112
  _globals['_S3MOUNT']._serialized_end=1221
  _globals['_EXECPAYLOAD']._serialized_start=1223
  _globals['_EXECPAYLOAD']._serialized_end=1292
  _globals['_EXECRESPONSE']._serialized_start=1294
  _globals['_EXECRESPONSE']._serialized_end=1385
  _globals['_RESOURCEUSAGE']._serialized_start=1388
  _globals['_RESOURCEUSAGE']._serialized_end=1527
  _globals['_OBJECTSTORAGEACCESS']._serialized_start=1530
  _globals['_OBJECTSTORAGEACCESS']._serialized_end=1660
  _globals['_STARTSANDBOXREQUEST']._serialized_start=1663
  _globals['_STARTSANDBOXREQUEST']._serialized_end=3038
  _globals['_STARTSANDBOXREQUEST_ENVIRONMENTVARIABLESENTRY']._serialized_start=2900
  _globals['_STARTSANDBOXREQUEST_ENVIRONMENTVARIABLESENTRY']._serialized_end=2971
  _globals['_STARTSANDBOXREQUEST_PODANNOTATIONSENTRY']._serialized_start=2973
  _globals['_STARTSANDBOXREQUEST_PODANNOTATIONSENTRY']._serialized_end=3038
  _globals['_STARTSANDBOXRESPONSE']._serialized_start=3041
  _globals['_STARTSANDBOXRESPONSE']._serialized_end=3598
  _globals['_STOPSANDBOXREQUEST']._serialized_start=3601
  _globals['_STOPSANDBOXREQUEST']._serialized_end=3822
  _globals['_STOPSANDBOXRESPONSE']._serialized_start=3824
  _globals['_STOPSANDBOXRESPONSE']._serialized_end=3908
  _globals['_GETSANDBOXREQUEST']._serialized_start=3910
  _globals['_GETSANDBOXREQUEST']._serialized_end=4018
  _globals['_GETSANDBOXRESPONSE']._serialized_start=4021
  _globals['_GETSANDBOXRESPONSE']._serialized_end=4617
  _globals['_LISTSANDBOXESREQUEST']._serialized_start=4620
  _globals['_LISTSANDBOXESREQUEST']._serialized_end=4906
  _globals['_LISTSANDBOXESRESPONSE']._serialized_start=4908
  _globals['_LISTSANDBOXESRESPONSE']._serialized_end=5000
  _globals['_SANDBOXINFO']._serialized_start=5003
  _globals['_SANDBOXINFO']._serialized_end=5592
  _globals['_DELETESANDBOXREQUEST']._serialized_start=5594
  _globals['_DELETESANDBOXREQUEST']._serialized_end=5705
  _globals['_DELETESANDBOXRESPONSE']._serialized_start=5707
  _globals['_DELETESANDBOXRESPONSE']._serialized_end=5793
  _globals['_EXECSANDBOXREQUEST']._serialized_start=5796
  _globals['_EXECSANDBOXREQUEST']._serialized_end=5961
  _globals['_EXECSANDBOXRESPONSE']._serialized_start=5963
  _globals['_EXECSANDBOXRESPONSE']._serialized_end=6048
  _globals['_ADDFILESANDBOXREQUEST']._serialized_start=6051
  _globals['_ADDFILESANDBOXREQUEST']._serialized_end=6238
  _globals['_ADDFILESANDBOXRESPONSE']._serialized_start=6240
  _globals['_ADDFILESANDBOXRESPONSE']._serialized_end=6327
  _globals['_RETRIEVEFILESANDBOXREQUEST']._serialized_start=6330
  _globals['_RETRIEVEFILESANDBOXREQUEST']._serialized_end=6480
  _globals['_RETRIEVEFILESANDBOXRESPONSE']._serialized_start=6483
  _globals['_RETRIEVEFILESANDBOXRESPONSE']._serialized_end=6612
  _globals['_PAUSESANDBOXREQUEST']._serialized_start=6614
  _globals['_PAUSESANDBOXREQUEST']._serialized_end=6724
  _globals['_PAUSESANDBOXRESPONSE']._serialized_start=6726
  _globals['_PAUSESANDBOXRESPONSE']._serialized_end=6811
  _globals['_RESUMESANDBOXREQUEST']._serialized_start=6813
  _globals['_RESUMESANDBOXREQUEST']._serialized_end=6924
  _globals['_RESUMESANDBOXRESPONSE']._serialized_start=6926
  _globals['_RESUMESANDBOXRESPONSE']._serialized_end=7012
  _globals['_RAWSANDBOXREQUEST']._serialized_start=7015
  _globals['_RAWSANDBOXREQUEST']._serialized_end=7494
  _globals['_RAWSANDBOXRESPONSE']._serialized_start=7497
  _globals['_RAWSANDBOXRESPONSE']._serialized_end=7900
  _globals['_ATCSERVICE']._serialized_start=8734
  _globals['_ATCSERVICE']._serialized_end=10413
# @@protoc_insertion_point(module_scope)
