# SPDX-FileCopyrightText: 2025 CoreWeave, Inc.
# SPDX-License-Identifier: Apache-2.0
# SPDX-PackageName: cwsandbox-client
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: coreweave/aviato/v1beta1/secrets.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'coreweave/aviato/v1beta1/secrets.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&coreweave/aviato/v1beta1/secrets.proto\x12\x18\x63oreweave.aviato.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"x\n\x14SecretStoreReference\x12\x1d\n\nstore_name\x18\x01 \x01(\tR\tstoreName\x12\x41\n\x07secrets\x18\x02 \x03(\x0b\x32\'.coreweave.aviato.v1beta1.SecretMappingR\x07secrets\"R\n\rSecretMapping\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x14\n\x05\x66ield\x18\x02 \x01(\tR\x05\x66ield\x12\x17\n\x07\x65nv_var\x18\x03 \x01(\tR\x06\x65nvVar\"?\n\x0eResolvedSecret\x12\x17\n\x07\x65nv_var\x18\x01 \x01(\tR\x06\x65nvVar\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\"O\n\x10WandBStoreConfig\x12\x17\n\x07\x61pi_url\x18\x01 \x01(\tR\x06\x61piUrl\x12\x12\n\x04team\x18\x02 \x01(\tR\x04teamJ\x04\x08\x03\x10\x04R\x08\x61udience\"\x93\x03\n\x0bSecretStore\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12,\n\x0forganization_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0eorganizationId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12V\n\rprovider_type\x18\x04 \x01(\x0e\x32\x31.coreweave.aviato.v1beta1.SecretStoreProviderTypeR\x0cproviderType\x12\x42\n\x05wandb\x18\n \x01(\x0b\x32*.coreweave.aviato.v1beta1.WandBStoreConfigH\x00R\x05wandb\x12>\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAtB\x11\n\x0fprovider_config\"\xe7\x01\n\x18\x43reateSecretStoreRequest\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x04name\x12[\n\rprovider_type\x18\x02 \x01(\x0e\x32\x31.coreweave.aviato.v1beta1.SecretStoreProviderTypeB\x03\xe0\x41\x02R\x0cproviderType\x12\x42\n\x05wandb\x18\n \x01(\x0b\x32*.coreweave.aviato.v1beta1.WandBStoreConfigH\x00R\x05wandbB\x11\n\x0fprovider_config\"e\n\x19\x43reateSecretStoreResponse\x12H\n\x0csecret_store\x18\x01 \x01(\x0b\x32%.coreweave.aviato.v1beta1.SecretStoreR\x0bsecretStore\"0\n\x15GetSecretStoreRequest\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x04name\"b\n\x16GetSecretStoreResponse\x12H\n\x0csecret_store\x18\x01 \x01(\x0b\x32%.coreweave.aviato.v1beta1.SecretStoreR\x0bsecretStore\"U\n\x17ListSecretStoresRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\"\x8e\x01\n\x18ListSecretStoresResponse\x12J\n\rsecret_stores\x18\x01 \x03(\x0b\x32%.coreweave.aviato.v1beta1.SecretStoreR\x0csecretStores\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"3\n\x18\x44\x65leteSecretStoreRequest\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x04name\"\x1b\n\x19\x44\x65leteSecretStoreResponse*k\n\x17SecretStoreProviderType\x12*\n&SECRET_STORE_PROVIDER_TYPE_UNSPECIFIED\x10\x00\x12$\n SECRET_STORE_PROVIDER_TYPE_WANDB\x10\x01\x32\x91\x05\n\x12SecretStoreService\x12\x9e\x01\n\x11\x43reateSecretStore\x12\x32.coreweave.aviato.v1beta1.CreateSecretStoreRequest\x1a\x33.coreweave.aviato.v1beta1.CreateSecretStoreResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1beta1/secretstores:\x01*\x12\x99\x01\n\x0eGetSecretStore\x12/.coreweave.aviato.v1beta1.GetSecretStoreRequest\x1a\x30.coreweave.aviato.v1beta1.GetSecretStoreResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1beta1/secretstores/{name}\x12\x98\x01\n\x10ListSecretStores\x12\x31.coreweave.aviato.v1beta1.ListSecretStoresRequest\x1a\x32.coreweave.aviato.v1beta1.ListSecretStoresResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1beta1/secretstores\x12\xa2\x01\n\x11\x44\x65leteSecretStore\x12\x32.coreweave.aviato.v1beta1.DeleteSecretStoreRequest\x1a\x33.coreweave.aviato.v1beta1.DeleteSecretStoreResponse\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/v1beta1/secretstores/{name}b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'coreweave.aviato.v1beta1.secrets_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SECRETSTORE'].fields_by_name['id']._loaded_options = None
  _globals['_SECRETSTORE'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_SECRETSTORE'].fields_by_name['organization_id']._loaded_options = None
  _globals['_SECRETSTORE'].fields_by_name['organization_id']._serialized_options = b'\340A\003'
  _globals['_SECRETSTORE'].fields_by_name['created_at']._loaded_options = None
  _globals['_SECRETSTORE'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_SECRETSTORE'].fields_by_name['updated_at']._loaded_options = None
  _globals['_SECRETSTORE'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_CREATESECRETSTOREREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATESECRETSTOREREQUEST'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_CREATESECRETSTOREREQUEST'].fields_by_name['provider_type']._loaded_options = None
  _globals['_CREATESECRETSTOREREQUEST'].fields_by_name['provider_type']._serialized_options = b'\340A\002'
  _globals['_GETSECRETSTOREREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETSECRETSTOREREQUEST'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_DELETESECRETSTOREREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETESECRETSTOREREQUEST'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_SECRETSTORESERVICE'].methods_by_name['CreateSecretStore']._loaded_options = None
  _globals['_SECRETSTORESERVICE'].methods_by_name['CreateSecretStore']._serialized_options = b'\202\323\344\223\002\032\"\025/v1beta1/secretstores:\001*'
  _globals['_SECRETSTORESERVICE'].methods_by_name['GetSecretStore']._loaded_options = None
  _globals['_SECRETSTORESERVICE'].methods_by_name['GetSecretStore']._serialized_options = b'\202\323\344\223\002\036\022\034/v1beta1/secretstores/{name}'
  _globals['_SECRETSTORESERVICE'].methods_by_name['ListSecretStores']._loaded_options = None
  _globals['_SECRETSTORESERVICE'].methods_by_name['ListSecretStores']._serialized_options = b'\202\323\344\223\002\027\022\025/v1beta1/secretstores'
  _globals['_SECRETSTORESERVICE'].methods_by_name['DeleteSecretStore']._loaded_options = None
  _globals['_SECRETSTORESERVICE'].methods_by_name['DeleteSecretStore']._serialized_options = b'\202\323\344\223\002\036*\034/v1beta1/secretstores/{name}'
  _globals['_SECRETSTOREPROVIDERTYPE']._serialized_start=1723
  _globals['_SECRETSTOREPROVIDERTYPE']._serialized_end=1830
  _globals['_SECRETSTOREREFERENCE']._serialized_start=164
  _globals['_SECRETSTOREREFERENCE']._serialized_end=284
  _globals['_SECRETMAPPING']._serialized_start=286
  _globals['_SECRETMAPPING']._serialized_end=368
  _globals['_RESOLVEDSECRET']._serialized_start=370
  _globals['_RESOLVEDSECRET']._serialized_end=433
  _globals['_WANDBSTORECONFIG']._serialized_start=435
  _globals['_WANDBSTORECONFIG']._serialized_end=514
  _globals['_SECRETSTORE']._serialized_start=517
  _globals['_SECRETSTORE']._serialized_end=920
  _globals['_CREATESECRETSTOREREQUEST']._serialized_start=923
  _globals['_CREATESECRETSTOREREQUEST']._serialized_end=1154
  _globals['_CREATESECRETSTORERESPONSE']._serialized_start=1156
  _globals['_CREATESECRETSTORERESPONSE']._serialized_end=1257
  _globals['_GETSECRETSTOREREQUEST']._serialized_start=1259
  _globals['_GETSECRETSTOREREQUEST']._serialized_end=1307
  _globals['_GETSECRETSTORERESPONSE']._serialized_start=1309
  _globals['_GETSECRETSTORERESPONSE']._serialized_end=1407
  _globals['_LISTSECRETSTORESREQUEST']._serialized_start=1409
  _globals['_LISTSECRETSTORESREQUEST']._serialized_end=1494
  _globals['_LISTSECRETSTORESRESPONSE']._serialized_start=1497
  _globals['_LISTSECRETSTORESRESPONSE']._serialized_end=1639
  _globals['_DELETESECRETSTOREREQUEST']._serialized_start=1641
  _globals['_DELETESECRETSTOREREQUEST']._serialized_end=1692
  _globals['_DELETESECRETSTORERESPONSE']._serialized_start=1694
  _globals['_DELETESECRETSTORERESPONSE']._serialized_end=1721
  _globals['_SECRETSTORESERVICE']._serialized_start=1833
  _globals['_SECRETSTORESERVICE']._serialized_end=2490
# @@protoc_insertion_point(module_scope)
